--- title: "wallaroo.records.telemetry_body" type: docs linkTitle: "wallaroo.records.telemetry_body" ---
def from_int(x: Any) -> int:
def to_class(c: Type[~T], x: Any) -> dict:
def from_str(x: Any) -> str:
def from_bool(x: Any) -> bool:
def from_list(f: Callable[[Any], ~T], x: Any) -> List[~T]:
def from_datetime(x: Any) -> datetime.datetime:
class ModelConfigElement:
ModelConfigElement(id: int)
@staticmethod
def from_dict(obj: Any) -> wallaroo.records.telemetry_body.ModelConfigElement:
def to_dict(self) -> dict:
class DeploymentModelConfig:
DeploymentModelConfig(model_config: wallaroo.records.telemetry_body.ModelConfigElement)
@staticmethod
def from_dict(obj: Any) -> wallaroo.records.telemetry_body.DeploymentModelConfig:
def to_dict(self) -> dict:
class Deployment:
Deployment( deploy_id: str, deployed: bool, deployment_model_configs: List[wallaroo.records.telemetry_body.DeploymentModelConfig], id: int)
@staticmethod
def from_dict(obj: Any) -> wallaroo.records.telemetry_body.Deployment:
def to_dict(self) -> dict:
class WelcomeModel:
WelcomeModel( file_name: str, id: int, model_id: str, model_version: uuid.UUID, updated_at: datetime.datetime)
@staticmethod
def from_dict(obj: Any) -> wallaroo.records.telemetry_body.WelcomeModel:
def to_dict(self) -> dict:
class WelcomePipeline:
WelcomePipeline(id: int, pipeline_tags: List[Any])
@staticmethod
def from_dict(obj: Any) -> wallaroo.records.telemetry_body.WelcomePipeline:
def to_dict(self) -> dict:
class WorkspaceModel:
WorkspaceModel(models: List[wallaroo.records.telemetry_body.ModelConfigElement])
@staticmethod
def from_dict(obj: Any) -> wallaroo.records.telemetry_body.WorkspaceModel:
def to_dict(self) -> dict:
class Workspace:
Workspace( archived: bool, created_at: datetime.datetime, created_by: uuid.UUID, id: int, models: List[wallaroo.records.telemetry_body.WorkspaceModel], name: str, pipelines: List[wallaroo.records.telemetry_body.ModelConfigElement])
@staticmethod
def from_dict(obj: Any) -> wallaroo.records.telemetry_body.Workspace:
def to_dict(self) -> dict:
class WallarooAPITelemetryDataV1:
WallarooAPITelemetryDataV1( api_key: str, deployments: List[wallaroo.records.telemetry_body.Deployment], models: List[wallaroo.records.telemetry_body.WelcomeModel], pipelines: List[wallaroo.records.telemetry_body.WelcomePipeline], users: int, workspaces: List[wallaroo.records.telemetry_body.Workspace])
@staticmethod
def from_dict(obj: Any) -> wallaroo.records.telemetry_body.WallarooAPITelemetryDataV1:
def to_dict(self) -> dict:
def wallaroo_api_telemetry_data_v1_from_dict(s: Any) -> wallaroo.records.telemetry_body.WallarooAPITelemetryDataV1:
def wallaroo_api_telemetry_data_v1_to_dict(x: wallaroo.records.telemetry_body.WallarooAPITelemetryDataV1) -> Any: